==> qmmp-0.10.10.tar.bz2: qmmp-0.10.10/src/plugins/Output/oss4/translations/oss4_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>OutputOSS4Factory</name>
    <message>
        <location filename="../outputoss4factory.cpp" line="38"/>
        <source>OSS4 Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="58"/>
        <source>About OSS4 Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="59"/>
        <source>Qmmp OSS4 Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="60"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>OSS4 Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="52"/>
        <source>Device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="71"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/plugins/Output/oss4/translations/oss4_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr">
<context>
    <name>OutputOSS4Factory</name>
    <message>
        <location filename="../outputoss4factory.cpp" line="37"/>
        <source>OSS4 Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="57"/>
        <source>About OSS4 Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="58"/>
        <source>Qmmp OSS4 Output Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../outputoss4factory.cpp" line="59"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>OSS4 Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="71"/>
        <source>Default</source>
        <translation>Öntanımlı</translation>
    </message>
</context>
</TS>
